@@ -1,6 +1,6 @@
 /* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
- * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2009-2011 Jannis Pohlmann <jannis@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -388,8 +388,8 @@ tumbler_file_info_array_new_with_flavor (const gchar *const     *uris,
 
   g_return_val_if_fail (uris != NULL, NULL);
 
-  num_uris = g_strv_length ((GStrv) uris);
-  num_mime_types = g_strv_length ((GStrv) mime_types);
+  num_uris = g_strv_length ((gchar **)uris);
+  num_mime_types = g_strv_length ((gchar **)mime_types);
 
   if (length != NULL)
     *length = MIN (num_uris, num_mime_types);
