@@ -1,6 +1,6 @@
 /* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
- * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2009-2011 Jannis Pohlmann <jannis@xfce.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +32,7 @@
 
 #include <tumbler/tumbler.h>
 
+#include <tumblerd/tumbler-component.h>
 #include <tumblerd/tumbler-cache-service.h>
 #include <tumblerd/tumbler-cache-service-dbus-bindings.h>
 #include <tumblerd/tumbler-utils.h>
@@ -77,12 +78,12 @@ static void tumbler_cache_service_cleanup_thread (gpointer      data,
 
 struct _TumblerCacheServiceClass
 {
-  GObjectClass __parent__;
+  TumblerComponentClass __parent__;
 };
 
 struct _TumblerCacheService
 {
-  GObject __parent__;
+  TumblerComponent __parent__;
 
   DBusGConnection *connection;
 
@@ -98,30 +99,30 @@ struct _TumblerCacheService
 
 struct _MoveRequest
 {
-  GStrv from_uris;
-  GStrv to_uris;
+  gchar **from_uris;
+  gchar **to_uris;
 };
 
 struct _CopyRequest
 {
-  GStrv from_uris;
-  GStrv to_uris;
+  gchar **from_uris;
+  gchar **to_uris;
 };
 
 struct _DeleteRequest
 {
-  GStrv uris;
+  gchar **uris;
 };
 
 struct _CleanupRequest
 {
   guint32 since;
-  gchar  *uri_prefix;
+  gchar **base_uris;
 };
 
 
 
-G_DEFINE_TYPE (TumblerCacheService, tumbler_cache_service, G_TYPE_OBJECT);
+G_DEFINE_TYPE (TumblerCacheService, tumbler_cache_service, TUMBLER_TYPE_COMPONENT);
 
 
 
@@ -254,12 +255,20 @@ tumbler_cache_service_move_thread (gpointer data,
   g_mutex_lock (service->mutex);
 
   if (service->cache != NULL)
-    tumbler_cache_move (service->cache, request->from_uris, request->to_uris);
+    {
+      tumbler_cache_move (service->cache, 
+                          (const gchar *const *)request->from_uris, 
+                          (const gchar *const *)request->to_uris);
+    }
 
   g_strfreev (request->from_uris);
   g_strfreev (request->to_uris);
   g_slice_free (MoveRequest, request);
 
+  /* allow the lifecycle manager to shut down tumbler again (unless
+   * other requests are still to be processed) */
+  tumbler_component_decrement_use_count (TUMBLER_COMPONENT (service));
+
   g_mutex_unlock (service->mutex);
 }
 
@@ -278,12 +287,20 @@ tumbler_cache_service_copy_thread (gpointer data,
   g_mutex_lock (service->mutex);
 
   if (service->cache != NULL)
-    tumbler_cache_copy (service->cache, request->from_uris, request->to_uris);
+    {
+      tumbler_cache_copy (service->cache, 
+                          (const gchar *const *)request->from_uris, 
+                          (const gchar *const *)request->to_uris);
+    }
 
   g_strfreev (request->from_uris);
   g_strfreev (request->to_uris);
   g_slice_free (CopyRequest, request);
 
+  /* allow the lifecycle manager to shut down tumbler again (unless
+   * other requests are still to be processed) */
+  tumbler_component_decrement_use_count (TUMBLER_COMPONENT (service));
+
   g_mutex_unlock (service->mutex);
 }
 
@@ -302,11 +319,15 @@ tumbler_cache_service_delete_thread (gpointer data,
   g_mutex_lock (service->mutex);
 
   if (service->cache != NULL)
-    tumbler_cache_delete (service->cache, request->uris);
+    tumbler_cache_delete (service->cache, (const gchar *const *)request->uris);
 
   g_strfreev (request->uris);
   g_slice_free (DeleteRequest, request);
 
+  /* allow the lifecycle manager to shut down tumbler again (unless
+   * other requests are still to be processed) */
+  tumbler_component_decrement_use_count (TUMBLER_COMPONENT (service));
+
   g_mutex_unlock (service->mutex);
 }
 
@@ -325,20 +346,32 @@ tumbler_cache_service_cleanup_thread (gpointer data,
   g_mutex_lock (service->mutex);
 
   if (service->cache != NULL)
-    tumbler_cache_cleanup (service->cache, request->uri_prefix, request->since);
+    {
+      tumbler_cache_cleanup (service->cache, 
+                             (const gchar *const *)request->base_uris, 
+                             request->since);
+    }
 
-  g_free (request->uri_prefix);
+  g_strfreev (request->base_uris);
   g_slice_free (CleanupRequest, request);
 
+  /* allow the lifecycle manager to shut down tumbler again (unless
+   * other requests are still to be processed) */
+  tumbler_component_decrement_use_count (TUMBLER_COMPONENT (service));
+
   g_mutex_unlock (service->mutex);
 }
 
 
 
 TumblerCacheService *
-tumbler_cache_service_new (DBusGConnection *connection)
+tumbler_cache_service_new (DBusGConnection         *connection,
+                           TumblerLifecycleManager *lifecycle_manager)
 {
-  return g_object_new (TUMBLER_TYPE_CACHE_SERVICE, "connection", connection, NULL);
+  return g_object_new (TUMBLER_TYPE_CACHE_SERVICE, 
+                       "connection", connection, 
+                       "lifecycle-manager", lifecycle_manager,
+                       NULL);
 }
 
 
@@ -406,8 +439,8 @@ tumbler_cache_service_start (TumblerCacheService *service,
 
 void
 tumbler_cache_service_move (TumblerCacheService   *service,
-                            const GStrv            from_uris,
-                            const GStrv            to_uris,
+                            const gchar *const    *from_uris,
+                            const gchar *const    *to_uris,
                             DBusGMethodInvocation *context)
 {
   MoveRequest *request;
@@ -415,23 +448,30 @@ tumbler_cache_service_move (TumblerCacheService   *service,
   dbus_async_return_if_fail (TUMBLER_IS_CACHE_SERVICE (service), context);
   dbus_async_return_if_fail (from_uris != NULL, context);
   dbus_async_return_if_fail (to_uris != NULL, context);
-  dbus_async_return_if_fail (g_strv_length (from_uris) == g_strv_length (to_uris), context);
+  dbus_async_return_if_fail (g_strv_length ((gchar **)from_uris) == g_strv_length ((gchar **)to_uris), context);
+
+  /* prevent the lifecycle manager to shut tumbler down before the
+   * move request has been processed */
+  tumbler_component_increment_use_count (TUMBLER_COMPONENT (service));
 
   request = g_slice_new0 (MoveRequest);
-  request->from_uris = g_strdupv (from_uris);
-  request->to_uris = g_strdupv (to_uris);
+  request->from_uris = g_strdupv ((gchar **)from_uris);
+  request->to_uris = g_strdupv ((gchar **)to_uris);
 
   g_thread_pool_push (service->move_pool, request, NULL);
 
   dbus_g_method_return (context);
+
+  /* try to keep tumbler alive */
+  tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
 }
 
 
 
 void
 tumbler_cache_service_copy (TumblerCacheService   *service,
-                            const GStrv            from_uris,
-                            const GStrv            to_uris,
+                            const gchar *const    *from_uris,
+                            const gchar *const    *to_uris,
                             DBusGMethodInvocation *context)
 {
   CopyRequest *request;
@@ -439,22 +479,29 @@ tumbler_cache_service_copy (TumblerCacheService   *service,
   dbus_async_return_if_fail (TUMBLER_IS_CACHE_SERVICE (service), context);
   dbus_async_return_if_fail (from_uris != NULL, context);
   dbus_async_return_if_fail (to_uris != NULL, context);
-  dbus_async_return_if_fail (g_strv_length (from_uris) == g_strv_length (to_uris), context);
+  dbus_async_return_if_fail (g_strv_length ((gchar **)from_uris) == g_strv_length ((gchar **)to_uris), context);
+
+  /* prevent the lifecycle manager to shut tumbler down before the
+   * copy request has been processed */
+  tumbler_component_increment_use_count (TUMBLER_COMPONENT (service));
 
   request = g_slice_new0 (CopyRequest);
-  request->from_uris = g_strdupv (from_uris);
-  request->to_uris = g_strdupv (to_uris);
+  request->from_uris = g_strdupv ((gchar **)from_uris);
+  request->to_uris = g_strdupv ((gchar **)to_uris);
 
   g_thread_pool_push (service->copy_pool, request, NULL);
 
   dbus_g_method_return (context);
+
+  /* try to keep tumbler alive */
+  tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
 }
 
 
 
 void
 tumbler_cache_service_delete (TumblerCacheService   *service,
-                              const GStrv            uris,
+                              const gchar *const    *uris,
                               DBusGMethodInvocation *context)
 {
   DeleteRequest *request;
@@ -462,19 +509,26 @@ tumbler_cache_service_delete (TumblerCacheService   *service,
   dbus_async_return_if_fail (TUMBLER_IS_CACHE_SERVICE (service), context);
   dbus_async_return_if_fail (uris != NULL, context);
 
+  /* prevent the lifecycle manager to shut tumbler down before the
+   * delete request has been processed */
+  tumbler_component_increment_use_count (TUMBLER_COMPONENT (service));
+
   request = g_slice_new0 (DeleteRequest);
-  request->uris = g_strdupv (uris);
+  request->uris = g_strdupv ((gchar **)uris);
 
   g_thread_pool_push (service->delete_pool, request, NULL);
 
   dbus_g_method_return (context);
+
+  /* try to keep tumbler alive */
+  tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
 }
 
 
 
 void
 tumbler_cache_service_cleanup (TumblerCacheService   *service,
-                               const gchar           *uri_prefix,
+                               const gchar *const    *base_uris,
                                guint32                since,
                                DBusGMethodInvocation *context)
 {
@@ -482,11 +536,18 @@ tumbler_cache_service_cleanup (TumblerCacheService   *service,
 
   dbus_async_return_if_fail (TUMBLER_IS_CACHE_SERVICE (service), context);
 
+  /* prevent the lifecycle manager to shut tumbler down before the
+   * cleanup request has been processed */
+  tumbler_component_increment_use_count (TUMBLER_COMPONENT (service));
+
   request = g_slice_new0 (CleanupRequest);
-  request->uri_prefix = g_strdup (uri_prefix);
+  request->base_uris = g_strdupv ((gchar **)base_uris);
   request->since = since;
 
   g_thread_pool_push (service->cleanup_pool, request, NULL);
 
   dbus_g_method_return (context);
+
+  /* try to keep tumbler alive */
+  tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
 }
