@@ -1,6 +1,6 @@
 /* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
- * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2009-2011 Jannis Pohlmann <jannis@xfce.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as
@@ -40,6 +40,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include <tumblerd/tumbler-component.h>
 #include <tumblerd/tumbler-manager.h>
 #include <tumblerd/tumbler-manager-dbus-bindings.h>
 #include <tumblerd/tumbler-specialized-thumbnailer.h>
@@ -97,12 +98,12 @@ static void             dump_thumbnailers                 (TumblerManager   *man
 
 struct _TumblerManagerClass
 {
-  GObjectClass __parent__;
+  TumblerComponentClass __parent__;
 };
 
 struct _TumblerManager
 {
-  GObject __parent__;
+  TumblerComponent __parent__;
 
   DBusGConnection *connection;
   TumblerRegistry *registry;
@@ -147,7 +148,7 @@ struct _ThumbnailerInfo
 
 
 
-G_DEFINE_TYPE (TumblerManager, tumbler_manager, G_TYPE_OBJECT);
+G_DEFINE_TYPE (TumblerManager, tumbler_manager, TUMBLER_TYPE_COMPONENT);
 
 
 
@@ -849,7 +850,7 @@ tumbler_manager_load_thumbnailer (TumblerManager *manager,
   GFile           *directory;
   GList          **list;
   GList           *lp;
-  GStrv            hash_keys;
+  gchar          **hash_keys;
   gchar           *base_name;
   gchar           *filename;
   gchar           *name;
@@ -1251,7 +1252,7 @@ tumbler_manager_thumbnailer_file_deleted (TumblerManager *manager,
   GFile           *directory;
   GList          **list;
   GList           *lp;
-  GStrv            hash_keys;
+  gchar          **hash_keys;
   gchar           *base_name;
   guint            n;
   gint             dir_index;
@@ -1411,7 +1412,7 @@ tumbler_manager_directory_deleted (TumblerManager *manager,
   GList           *delete_keys = NULL;
   GList          **list;
   GList           *lp;
-  GStrv            hash_keys;
+  gchar          **hash_keys;
   guint            n;
 
   g_return_if_fail (TUMBLER_IS_MANAGER (manager));
@@ -1800,11 +1801,15 @@ dump_thumbnailers (TumblerManager *manager)
 
 
 TumblerManager *
-tumbler_manager_new (DBusGConnection *connection,
-                     TumblerRegistry *registry)
+tumbler_manager_new (DBusGConnection         *connection,
+                     TumblerLifecycleManager *lifecycle_manager,
+                     TumblerRegistry         *registry)
 {
-  return g_object_new (TUMBLER_TYPE_MANAGER, "connection", connection, 
-                       "registry", registry, NULL);
+  return g_object_new (TUMBLER_TYPE_MANAGER, 
+                       "connection", connection, 
+                       "registry", registry, 
+                       "lifecycle-manager", lifecycle_manager, 
+                       NULL);
 }
 
 
@@ -1869,7 +1874,7 @@ tumbler_manager_start (TumblerManager *manager,
   /* load thumbnailers installed into the system permanently */
   tumbler_manager_load (manager);
 
-  /* this is how I roll */
+  /* done initializing and loading all permanent thumbnailers */
   return TRUE;
 }
 
